clear
capture log close
log using "log/OSS measures.log", replace

set more off

foreach y of global YEAR {

use data/AGGmaster`y', clear

*******************************************************************************************************************
*** Following OECD STI Working Paper 'The measurement of Globalisation using International Input-Output Tables'  **
*** page page 16, we calculate the outsourcing intensity as the ratio of total imported intermediate inputs to   **
*** total non energy inputs.  They calculate the denominator as imports + domestic.  Note this is what the       **
*** Total IO tab represents.                                                                                     **
*******************************************************************************************************************

generate OSS_`y' = (total_nonenergy_int_imports / total_purchase)

generate OSS_narrow_`y' = (narrow / total_purchase)

generate OSS_M_`y' = ( total_materials_int_imports / total_purchase )

generate OSS_S_`y' = ( total_services_int_imports / total_purchase )

*******************************************************************
**  Generate Geishecker and Gorg (2008) measure of outsourcing   **
**   using total output                                          **
*******************************************************************

generate GG_OSS_`y' = ( total_int_imports / total_output ) 

generate GG_OSS_narrow_`y' = (narrow / total_output )


***************************************************************
** Generate the measure of IMPINT used by both F&H and A&W   **
** Note, they use IMF balance of payments trade data to      **
** calculate this statistic, and it is used as an estimate   **
** to help calculate intermediate imports                    **
** Using the I-O tables, we already have intermediate imports**
** and so this is redundant.  Imports and Production come    **
** from the total tab of the I-O table, and are the sum of   **
** the rows in for each industry.  Note, these totals do not **
** exclude any energy intensive industries.                  **
***************************************************************

generate impint = imports / production


*******************************************************************
** This loop calculates the weight of each input into the total  **
** purchase by the industry.                                     **
** w(i) = purchase of input j by industry i divided by total     **
**   purchase of all non energy inputs by industry i.            **
** In this set up, observation [_n] would be input j.  That is,  ** 
** each observation by variable is the input j.  This is due to  ** 
** the square matrix of the input output table.                  **
*******************************************************************

do prog/rename

mkmat total1-total36, matrix(T)

mkmat total_purchase, matrix(TT)

matrix w = J(36,36,0)

forvalues i = 1(1)36 {
  forvalues k = 1(1)36 {
    matrix w[`k',`i'] = T[`k',`i'] / TT[`i',1]
   }
  }


************************************************************************
** Generate the matrix FH_IMPINT, which is a N x 1 matrix of          **
** import intensity calculated with final goods.                      **
** Each observation matches up with the corresponding industry weight,**
** which is why the index `j' moves through the appropriate row.      **
************************************************************************

mkmat impint, matrix(FH_impint)
 
matrix FH_OSS = J(36,36,0)

forvalues j = 1(1)36 {
  forvalues i = 1(1)36 {
    matrix FH_OSS[`i',`j'] = w[`i',`j'] * FH_impint[`i',1]
   }
  }

**********************************************************************
** The wide measure of outsourcing looks at all inputs into a given **
** industry.  This is the column sum.                               **
** We follow the same idea as in 'Total_Purchase.Do'                **
** Transpose the matrix OSS, sum across rows                        **
**********************************************************************

matrix FH_OSST = FH_OSS'
svmat FH_OSST, names(col)

** We shouldn't have the problem of energy industries with OSS > 1 under the aggregated scenario.  
** Now, inputs are expressed as a percentage of total non energy inputs of all industries in the class group
** Thus, a large input from one industry is a smaller ratio of all inputs for the whole class
** (essentially, we inflated the denominator)

egen FH_OSS_`y' = rowtotal(r1-r36)

** Exclude energy from the numerator; this is class 2 and class 3.  Note: this also exludes
** chemicals/pharmaceuticals and non-energy mining, due to the aggregation of the IAB levels

generate FH_OSS_`y'_exclenergy = FH_OSS_`y' - r2 - r3

** Generate measures of materials and service outsourcing.  This is simply the sum of the relevant industries.  
** See page 10, Amiti and Wei (2005)
** Remember that the r1-r36 is consecutive; we are missing isic industries due to aggregation, 
** so r10 is not ISIC 10 
** To find the correct r, list class variables from 1 to 48; the position [_n] of each class is the corresponding r 

/* To stay consistent, we exclude energy industries from material inputs, r2 and r3 */

egen FH_OSS_M_`y' = rowtotal(r1 r4 r5 r6 r7 r8 r9 r10 r11 r13) 

egen FH_OSS_S_`y' = rowtotal(r25 r26 r27 r28 r29 r30 r31 r32 r33 r34 r35)

drop r1-r36


**********************************************************************
** OSS and OSS_Wide now both make up a 48 x 48 square matrix        **
** I use this property to easily make two column vectors            **
** for the variables OSS_wide and OSS_narrow using the vecdiag()    **
** function, which takes the diagonal and makes a column vector.    **
** The column vectors can be more easily worked with in excel or in **
** regressions in Stata.                                            **
**********************************************************************

matrix FH_OSS_narrow = vecdiag(FH_OSS)
matrix FH_OSS_Narrow = FH_OSS_narrow'
svmat FH_OSS_Narrow, name(FH_OSS_Narrow)

rename FH_OSS_Narrow FH_OSS_narrow_`y'

save data/AGGmaster`y', replace

}

log close
exit



