* Program file of the project "Outsourcing and Firm Productivity" - 11_FrontierPrep.do
* Contents: Prepare data for Frontier estimation of production function  
*           Note that we calculate two different measures of ln(cap) based on two different measures of capital stock, calculated in 10_CapitalStock
*           lncap1 is based on the KLEMS capital/output ratio measure of capital
*           lncap2 is based on the PIM estimate of capital stock using industry growth rates

* Level of Aggregation:  Firm level IAB data, industry classification according to the variable class

clear 
clear matrix
set mem 600m

capture log close
log using "log/11_FrontierPrep.log", replace

#delimit ;

use data/10_CapitalStock.dta ; 

* Drop mining/quarrying plus electricity and chemicals/coke/refined petroluem from our analysis ;
drop if class == 2 | class == 3 ;

* Change all values to missing, if coded with an -8 or -9 ;
mvdecode _all, mv(-9 -8) ;

* Add labels to the HHI variables (may 2010 update for clarity);
label var HHI_Major00 "HHI Major 2000";
label var HHI_Minor00 "HHI Minor 2000";
label var HHI_Major05 "HHI Major 2005";
label var HHI_Minor05 "HHI Minor 2005";

************************************************************************;
* July 19 2009 Correspondence from Sumon Bhaumik:                       ;
* I think we should control for the following firm-level variables:     ;
*                                                                       ;
*(a) Age of the company (= YYYY - Year company founded)                 ;
*(b) Size of the company (= Sales in YYYY)                              ;
*(c) Quality of capital                                                 ;
*(d) Quality of labour (= Total skilled employees/Total employees)      ; 
*(e) Ownership                                                          ;
*(f) Works council                                                      ;
************************************************************************;

*************************************************************************;
** Oct 6 2009 Update:									 ; 
** As for profits, the formula would be                                  ;
**                                                                       ; 
**   profit = total output - intermediate input - wage bill              ;
*************************************************************************;

** (A) Generate variable for the age of company ;
**     Assign an age of 10 to companies founded before 1990 ;

** Note: CA added the code for age2000 and age2005 in March 2010;
**        We use the variables agenewYYYY in the regression specification;
**        We'll attempt to use ageYYYY as IV;

** Note: The age variable seems to be very tricky - h73 is the dummy for before or after 1990;
**         but in several cases, h73 is missing, and the year of founding is provided.;
**       So we'll create a before/after 1990 dummy based on the combination of the two variables;
**        Such that agenew = 0 if founded on or before 1990, 1 after ;

generate age2000 = 10 if h73 == 1;
replace age2000 = ( 2000 - age00 ) if h73 == 2 ;
replace age2000 = ( 2000 - age00 ) if h73 == . ;
replace age2000 = 10 if age2000 > 11 & age2000 < . ;
label var age2000 "Age in number of years, left censored at 10";

generate agenew2000 = 0 if age2000 == 10 ;
replace agenew2000 = 1 if age2000 < 10;
label var agenew2000 "Age dummy, founded 1990 or earlier";

generate age2005 = 15 if m92 == 1;
replace age2005 = ( 2005 - age05 ) if m92 == 2 ;
replace age2005 = ( 2005 - age05 ) if m92 == . ;
label var age2005 "Age in number of years";

generate agenew2005 = 0 if age2005 == 15 ;
replace agenew2005 = 1 if age2005 < 15;
label var agenew2005 "Age dummy, founded 1990 or earlier";

** (B) Generate measures of size of company (measured as sales in YYYY) ;
**     These variables are PPIoutputYY, and expressed in 1995 dollars ;
**     Nominal dollars are outputYY ;

** (C) Generate measures of quality of capital ;
**     These are variables qualcapYY ;
**     Values range from 1 (state of the art) to 5 (completely outdated) ;
**     Note: CA added new measures of qualcap in March 2010 to be used as IV ;


generate qualcapnew00 = 6 - qualcap00 ;
generate qualcapnew99 = 6 - qualcap99 ;
generate qualcapnew95 = 6 - qualcap95 ;

generate qualcapnew05 = 6 - qualcap05 ;
generate qualcapnew03 = 6 - qualcap03 ;

** (D) Generate measures of Quality of labor as ratio of total skilled employees to total employees ;
**     NOTE: Need to have IAB explain employment variables - which variable is correct to use for total employees? ;
**     NOTE: Need to update Do files 2 and 3 to add correct total employee variable from IAB advice ;

generate skill_labour00 = skill_emp00 / ( emp00 ) ;
replace skill_labour00 = . if skill_labour00 > 1 ;
generate skill_labour99 = skill_emp99 / ( emp99 ) ;
generate skill_labour95 = skill_emp95 / ( emp95 ) ;

generate skill_labour05 = skill_emp05 / ( emp05 ) ;
generate skill_labour04 = skill_emp04 / ( emp04 ) ;


** (E) Generate Ownership Variable ;
**     Variable named ownerYY ;
**     Values (1 = west german  2 = east german  3 = foreign  4 = public  5 = not a majority owner  6 = not known) ;

generate eastgerman00 = owner00 == 2 ;
generate foreign00 = owner00 == 3 ;
generate public00 = owner00 == 4 ;
generate other00 = owner00 == 5 | owner00 == 6 ;

generate eastgerman05 = owner05 == 2 ;
generate foreign05 = owner05 == 3 ;
generate public05 = owner05 == 4 ;
generate other05 = owner05 == 5 | owner00 == 6 ;

** (F) Generate Works Council Variable ;
**     Variable named workcouncYY ;
**     Values (1 = Yes  2 = No ) ;

generate workcouncnew00 = workcounc00 == 1 ;
generate workcouncnew05 = workcounc05 == 1 ;

*** May 2010 Addition;
** We should experiment with interaction between outsourcing and two other variables;
** (a) apropos an excellent observation that you have made about the soft costs of outsourcing;
**      we should interact outsourcing with dummies that indicate where outside Germany a firm has operating experience; 
** (b) we should interact it with the union dummy to see whether outsourcing;
**      that (presumably) has the blessing of the unions are more beneficial;

generate FH_OSS_ownership00 = foreign00*FH_OSS_2000;
label var FH_OSS_ownership00 "Foreign FH Outsourcing Interaction";
generate OSS_ownership00 = foreign00*OSS_2000; 
label var OSS_ownership00 "Foreign OSS Outsourcing Interaction";

generate FH_OSS_ownership05 = foreign05*FH_OSS_2005;
label var FH_OSS_ownership05 "Foreign FH Outsourcing Interaction";
generate OSS_ownership05 = foreign05*OSS_2005; 
label var OSS_ownership05 "Foreign OSS Outsourcing Interaction";

generate FH_OSS_union00 = workcouncnew00*FH_OSS_2000;
label var FH_OSS_union00 "Union FH Outsourcing Interaction";
generate OSS_union00 = workcouncnew00*OSS_2000; 
label var OSS_union00 "Union OSS Outsourcing Interaction";

generate FH_OSS_union05 = workcouncnew05*FH_OSS_2005;
label var FH_OSS_union05 "Union FH Outsourcing Interaction";
generate OSS_union05 = workcouncnew05*OSS_2005; 
label var OSS_union05 "Union OSS Outsourcing Interaction";


** Generate measures of total pay ;
generate totpay00 = pay00 * 12 ;
generate totpay05 = pay05 * 12 ;

** Replace missing values of intermediate inputs ;
** Note: a missing value (-8 or -9) now has an intinput value of -0.08 or -0.09 because of the data transformation ;

replace intinput00 = . if intinput00 < 0 | intinput00 > 1;
replace intinput05 = . if intinput05 < 0 | intinput05 > 1;

** Generate measures of Profit ;
generate cost00 = output00 * intinput00 ;
generate cost05 = output05 * intinput05 ;
generate profit00 = output00 - cost00 ;
generate profit05 = output05 - cost05 ;

summarize cost00 profit00 intinput00 output00, detail;
summarize cost05 profit05 intinput05 output05, detail;

** Generate measures of Value Added ;

generate va00 = (1 - intinput00) * output00 ;
generate va05 = (1 - intinput05) * output05 ;
summarize va00 va05 ;

generate lnva00 = ln(va00) ;
generate lnva05 = ln(va05) ;

***************************************************;
** CHANGE MEASURES OF CAPITAL STOCK HERE         **;
***************************************************;

** Generate log measures of labor and capital ;
** Currently, we use PIM measures of Capital Stock.  We will gain additional observations if we use KLEMS values instead ;

generate lncap1_00 = ln(Klems00) ;
label var lncap1_00 "Klems Capital Stock" ;

generate lncap1_05 = ln(Klems05) ;
label var lncap1_05 "Klems Capital Stock" ;

generate lncap2_00 = ln(K_PIMEST_00) ;
label var lncap2_00 "G est Capital Stock" ;

generate lncap2_05 = ln(K_PIMEST_05) ;
label var lncap2_05 "G est Capital Stock" ;

generate lnlabor00 = ln(totpay00) ;
generate lnlabor05 = ln(totpay05) ;

**************************************************************************; 
* Create 10 dummy variables for Frontier analysis                         ;
* Indice of dummy variable is equal to value of Class                     ;
* See Concordance do file or Master Classification Excel Worksheet        ;
**************************************************************************;

generate d4 = class == 4 ;
label var d4 "Rubber and Plastic" ;

generate d5 = class == 5 ;
label var d5 "Other Non-Metallic" ;

generate d6 = class == 6 ;
label var d6 "Manufacture of basic metals" ;

generate d8 = class == 8 ;
label var d8 "Machinery" ;

generate d9 = class == 9 ;
label var d9 "Transport" ;

generate d11 = class == 11 ;
label var d11 "Electrical" ;

generate d13 = class == 13 ;
label var d13 "Wood Products" ;

generate d14 = class == 14 ;
label var d14 "Pulp, Paper " ;

generate d15 = class == 15 ;
label var d15 "Textiles" ;
 
generate d16 = class == 16 ;
label var d16 "Food/Bev" ;

** Use six different loops to create the log of each capital and labour input for each industry ;

** 2000 data ;
local dummy "4 5 6 8 9 11 13 14 15 16" ;
foreach x of local dummy { ;
 generate lnd`x'k1_00 =  d`x' * lncap1_00   ;  
 replace lnd`x'k1_00 = 0 if lnd`x'k1_00 == .  ;

 generate lnd`x'k2_00 = d`x' * lncap2_00 ;
 replace  lnd`x'k2_00 = 0 if lnd`x'k2_00 == .;
   } ;

local dummy "4 5 6 8 9 11 13 14 15 16" ;
foreach x of local dummy { ;
 generate lnd`x'L00 =  d`x' * lnlabor00  ;
 replace lnd`x'L00 = 0 if lnd`x'L00 == .   ;  
    } ;

** 2005 data ;
local dummy "4 5 6 8 9 11 13 14 15 16" ;
foreach x of local dummy { ;
 generate lnd`x'k1_05 =  d`x' * lncap1_05   ; 
 replace lnd`x'k1_05 = 0 if lnd`x'k1_05 == .  ;

 generate lnd`x'k2_05 =  d`x' * lncap2_05   ; 
 replace lnd`x'k2_05 = 0 if lnd`x'k2_05 == .  ;
  } ;

local dummy "4 5 6 8 9 11 13 14 15 16" ;
foreach x of local dummy { ;
 generate lnd`x'L05 = d`x' * lnlabor05  ;
 replace lnd`x'L05 = 0 if lnd`x'L05 == .  ;
   } ;

** Generate dummy variable to indicate a clean data set for Frontier analysis ;
generate year00sample_1 = 1 if lnva00 !=. & lncap1_00 !=. & lnlabor00 !=. & voltype00 == 1;
generate year05sample_1 = 1 if lnva05 !=. & lncap1_05 !=. & lnlabor05 !=. ; 
/* Note no voltype for the year 2005 */;

generate year00sample_2 = 1 if lnva00 !=. & lncap2_00 !=. & lnlabor00 !=. & voltype00 == 1;
generate year05sample_2 = 1 if lnva05 !=. & lncap2_05 !=. & lnlabor05 !=. ; 
/* Note no voltype for the year 2005 */;


*********************************************************************************;
* Correspondence from Sumon Bhaumik, July 19 2009:                              *;
*I have given some thought to what we would like to estimate in the first run   *;
*when I am in Nuremberg. I think we should try multiple measures of performance *;
* How about the following:                                                      *; 
*                                                                                ;  
*(1) technical efficiency (what we are currently estimating using the frontier model);
*(2) labour productivity (= Sales in YYYY/Total employees YYYY)                 *;
*(3) "profitability" 1 (= Profits in YYYY/Total employees YYYY)                 *;
*(4) "profitability" 2 (= Profits in YYYY/Sales in YYYY, i.e., profit margin)   *;
*                                                                               *;
*********************************************************************************;

****************************************; 
* Generate appropriate LHS variable    *;
****************************************;
* NOTE: March 2010;
* We use total employee measures, denoted by tl_prod and t_ppe;
*  Earlier version (commented out) incorrectly used skill plus nonskill ;

* (2) labour productivity (=sales in YYYY / Total employees YYYY ) ;

*generate l_prod00 = output00 / (skill_emp00 + nonskill_emp00 ) ;
*label var l_prod00 "labor productivity 2000"  ;

*generate l_prod05 = output05 / (skill_emp05 + nonskill_emp05 ) ;
*label var l_prod05 "labor productivity 2005"  ;

* (3) Profits per employee ;

*generate profit_per_emp00 = profit00 / (skill_emp00 + nonskill_emp00 ) ;
*label var profit_per_emp00 "Profit per Employee 2000"  ;

*generate profit_per_emp05 = profit05 / (skill_emp05 + nonskill_emp05 ) ;
*label var profit_per_emp05 "Profit per Employee 2005"  ;

** Generate measures using the total employees variable i0ges00;
** Notation: Includes a T for 'total labor' ;

* (2T) labour productivity (=sales in YYYY / Total employees YYYY ) ;

generate tl_prod00 = output00 / (emp00) ;
label var tl_prod00 "labor productivity 2000 using emp00"  ;

generate tl_prod05 = output05 / (emp05) ;
label var tl_prod05 "labor productivity 2005 using emp05"  ;

* (3T) Profits per employee ;

generate tprofit_per_emp00 = profit00 / (emp00) ;
label var tprofit_per_emp00 "Profit per Employee 2000 using emp00"  ;

generate tprofit_per_emp05 = profit05 / (emp05) ;
label var tprofit_per_emp05 "Profit per Employee 2005 using emp05"  ;


* (4) Profits per sales  ;

generate profit_per_sales00 = profit00 / output00 ;
label var profit_per_sales00 "Profit per sales 2000" ;

generate profit_per_sales05 = profit05 / output05 ;
label var profit_per_sales05 "Profit per sales 2005" ;

** Generate appropriate interaction terms for independent variables ;

generate lnoutput00 = ln(output00) ;
generate FH_OSS_output00 = FH_OSS_2000*lnoutput00 ;
generate OSS_output00 = OSS_2000*lnoutput00 ;

generate lnoutput05 = ln(output05) ;
generate FH_OSS_output05 = FH_OSS_2005*lnoutput05 ;
generate OSS_output05 = OSS_2005*lnoutput05 ;

generate lnoutput95 = ln(output95) ;
generate lnoutput99 = ln(output99) ;
generate lnoutput04 = ln(output04) ;



** March 2010 Update;
** Need to add new measures of log labor productivity, log capital per employee, log intermediate inputs per employee;

* log measures of labor productivity;
generate ln_tlprod00 = ln(tl_prod00);
generate ln_tlprod05 = ln(tl_prod05);

* log measure of capital per employee;

generate ln_capemp1_95 = ln(Klems95 / emp95);
label var ln_capemp1_95 "log capital per emp 95, KLEMS";

generate ln_capemp1_99 = ln(Klems99 / emp99);
label var ln_capemp1_99 "log capital per emp 99, KLEMS";

generate ln_capemp1_00 = ln(Klems00 / emp00);
label var ln_capemp1_00 "log capital per emp 00, KLEMS";

generate ln_capemp1_04 = ln(Klems04 / emp04);
label var ln_capemp1_04 "log capital per emp 04, KLEMS";

generate ln_capemp1_05 = ln(Klems05 / emp05);
label var ln_capemp1_05 "log capital per emp 05, KLEMS";

generate ln_capemp2_00 = ln(K_PIMEST_00 / emp00);
label var ln_capemp2_00 "log capital per emp 00, K_PIMEST";

generate ln_capemp2_05 = ln(K_PIMEST_05 / emp05);
label var ln_capemp2_05 "log capital per emp 05, K_PIMEST";

** Note: May 2010 decision not to include materials per employee bc IAB measure includes wages;

* log measures of materials per employee;
*generate ln_matemp00 = ln( (intinput00*output00) / emp00);
*replace ln_matemp00 = . if output00 == . | intinput00 == . | emp00 == . ;
*label var ln_matemp00 "log int inputs per emp";

*generate ln_matemp05 = ln( (intinput05*output05) / emp05);
*replace ln_matemp05 = . if output05 == . | intinput05 == . | emp05 == . ;
*label var ln_matemp05 "log int inputs per emp";


* Data to be used in the regression files 20 thru 40 - includes industry 13 and 14 ;
save "data/11_FrontierPrep", replace;


log close ;
